fisx: Member List

fisx

fisx::Element Member List

This is the complete list of members for fisx::Element, including all inherited members.

clearCache() | fisx::Element |
Element() | fisx::Element |
Element(std::string name, int z) | fisx::Element |
emptyCascadeCache() (defined in fisx::Element) | fisx::Element |
extractEdgeEnergiesFromMassAttenuationCoefficients() (defined in fisx::Element) | fisx::Element |
extractEdgeEnergiesFromMassAttenuationCoefficients(const std::vector< double > &energies, const std::vector< double > &muPhotoelectric) (defined in fisx::Element) | fisx::Element |
fillCache(const std::vector< double > &energy) | fisx::Element |
fillCascadeCache() (defined in fisx::Element) | fisx::Element |
getAtomicMass() const | fisx::Element |
getAtomicNumber() const | fisx::Element |
getAugerRatios(std::string subshell) (defined in fisx::Element) | fisx::Element |
getBindingEnergies() const | fisx::Element |
getCacheSize() const | fisx::Element |
getCascadeModifiedVacancyDistribution(const std::map< std::string, double > &distribution) const (defined in fisx::Element) | fisx::Element |
getColumn() const | fisx::Element |
getCosterKronigRatios(std::string subshell) (defined in fisx::Element) | fisx::Element |
getDensity() const | fisx::Element |
getEmittedXRayLines(const double &energy=1000.) const | fisx::Element |
getExcitedShells(const double &energy) const | fisx::Element |
getFluorescenceRatios(const std::string &subshell) const | fisx::Element |
getInitialPhotoelectricVacancyDistribution(const std::vector< double > &energies) const | fisx::Element |
getInitialPhotoelectricVacancyDistribution(const double &energy) const | fisx::Element |
getInterpolationIndices(const std::vector< double > &, const double &) const | fisx::Element |
getLongName() const | fisx::Element |
getMassAttenuationCoefficients() const | fisx::Element |
getMassAttenuationCoefficients(const std::vector< double > &energy) const | fisx::Element |
getMassAttenuationCoefficients(const double &energy) const | fisx::Element |
getName() const | fisx::Element |
getNonradiativeTransitions(const std::string &subshell) const (defined in fisx::Element) | fisx::Element |
getPartialPhotoelectricMassAttenuationCoefficients(const double &energy) const | fisx::Element |
getPhotoelectricExcitationFactors(const std::vector< double > &energy, const std::vector< double > &weights=std::vector< double >()) const | fisx::Element |
getPhotoelectricExcitationFactors(const double &energy, const double &weight=1.0) const | fisx::Element |
getRadiativeTransitions(const std::string &subshell) const (defined in fisx::Element) | fisx::Element |
getRow() const | fisx::Element |
getShell(const std::string &) const (defined in fisx::Element) | fisx::Element |
getShellConstants(const std::string &subshell) const (defined in fisx::Element) | fisx::Element |
getTransitionEnergy(const std::string &transition) const | fisx::Element |
getXRayLines(const std::string &family="") const | fisx::Element |
getXRayLinesFromVacancyDistribution(const std::map< std::string, double > &distribution, const int &cascade=1, const int &useFluorescenceYield=1) const | fisx::Element |
isCacheEnabled() const | fisx::Element |
isCascadeCacheFilled() const (defined in fisx::Element) | fisx::Element |
setAtomicMass(const double &mass) | fisx::Element |
setAtomicNumber(const int &z) | fisx::Element |
setBindingEnergies(std::map< std::string, double > bindingEnergies) | fisx::Element |
setBindingEnergies(std::vector< std::string > labels, std::vector< double > energies) | fisx::Element |
setCacheEnabled(const int &flag=1) | fisx::Element |
setCascadeCacheEnabled(const int &flag=1) | fisx::Element |
setColumn(const int &) | fisx::Element |
setDensity(const double &) | fisx::Element |
setLongName(const std::string &name) | fisx::Element |
setMassAttenuationCoefficients(const std::vector< double > &energies, const std::vector< double > &photoelectric, const std::vector< double > &coherent, const std::vector< double > &incoherent, const std::vector< double > &pair) | fisx::Element |
setMassAttenuationCoefficients(const std::vector< double > &energies, const std::vector< double > &photoelectric, const std::vector< double > &coherent, const std::vector< double > &incoherent) | fisx::Element |
setName(const std::string &name) | fisx::Element |
setNonradiativeTransitions(std::string subshell, std::vector< std::string >, std::vector< double > values) (defined in fisx::Element) | fisx::Element |
setNonradiativeTransitions(std::string subshell, std::map< std::string, double > values) (defined in fisx::Element) | fisx::Element |
setPartialPhotoelectricMassAttenuationCoefficients(const std::string &shell, const std::vector< double > &energy, const std::vector< double > &partialPhotoelectric) | fisx::Element |
setRadiativeTransitions(std::string subshell, std::map< std::string, double > values) (defined in fisx::Element) | fisx::Element |
setRadiativeTransitions(std::string subshell, std::vector< std::string >, std::vector< double > values) (defined in fisx::Element) | fisx::Element |
setRow(const int &) | fisx::Element |
setShellConstants(std::string subshell, std::map< std::string, double > constants) (defined in fisx::Element) | fisx::Element |
setTotalMassAttenuationCoefficient(const std::vector< double > &energies, const std::vector< double > &total) | fisx::Element |
updateCache(const std::vector< double > &energy) | fisx::Element |